# $Id: acoc.spec,v 1.34 2005/02/27 01:13:32 ianmacd Exp $
#
# build with '--with links' to package symlinks
#
# build with '--with per_user' to require ~/.acoc to exist before PATH is
#   modified from /etc/profile.d/
#
# build with '--with google' to apply patch to allow acoc to function with
#   minimal interference in the Google work environment.

Summary: acoc colours the output of arbitrary command-line programs
Name: acoc
Version: 0.7.1
Release: 1
License: GPL
Group: Applications/Ruby
Source: http://www.caliban.org/files/ruby/%{name}-%{version}.tar.gz
Patch0: acoc-per_user.diff
Patch1: acoc-google.diff
URL: http://www.caliban.org/ruby/
Packager: Ian Macdonald <ian@caliban.org>
BuildRoot: /var/tmp/%{name}-%{version}
BuildArch: noarch
BuildRequires: ruby
Requires: ruby, ruby-term-ansicolor
Obsoletes: rc, rcf
%define links %{?_with_links:1}%{?!_with_links:0}
%define per_user %{?_with_per_user:1}%{?!_with_per_user:0}
%define google %{?_with_google:1}%{?!_with_google:0}

%description
acoc is a utility for adding colour to the output of arbitrary command-line
programs. Using a configuration file, regular-expression based pattern-
matching rules and colour sets can be defined for the programs that you use. A
set of default patterns can also be defined, which will be used to colour the
output of programs that have no specific matching rules of their own.

%clean 
rm -rf $RPM_BUILD_ROOT

%prep
%setup -n %{name}-%{version}
%if %{per_user}
%patch0 -p1
%endif
%if %{google}
%patch1 -p1
%endif

%install
rm -rf $RPM_BUILD_ROOT
make install ROOT=$RPM_BUILD_ROOT%{_prefix}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/profile.d
mkdir -p $RPM_BUILD_ROOT%{_prefix}/%{name}/bin
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man{1,5}
install %{name}.shell  $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/%{name}.sh
install %{name}.csh $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/%{name}.csh
install %{name}.1 $RPM_BUILD_ROOT%{_mandir}/man1/%{name}.1
install %{name}.conf.5 $RPM_BUILD_ROOT%{_mandir}/man5/%{name}.conf.5
gzip -9 $RPM_BUILD_ROOT%{_mandir}/man1/%{name}.1
gzip -9 $RPM_BUILD_ROOT%{_mandir}/man5/%{name}.conf.5
mv $RPM_BUILD_ROOT%{_prefix}/etc/%{name}.conf $RPM_BUILD_ROOT%{_sysconfdir}/

%if %{links}
cd $RPM_BUILD_ROOT%{_prefix}/%{name}/bin
for i in $(ruby -ne \
  'BEGIN { $commands = [] };
   next unless $_ =~ /^\[([^\]]+)\]$/; \
   $commands += $_[1..$_.length-3].split(/\s*,\s*/).each do |x|
     x.sub!(%r([\s/].*$), "")
   end;
   END { puts $commands.sort.uniq }' \
   $RPM_BUILD_ROOT%{_sysconfdir}/acoc.conf); do
  ln -sf ../../bin/%{name} $i
done
cd -
%endif

find $RPM_BUILD_ROOT -type f -o -type l | grep -v /etc/ | \
    ruby -pe 'sub(%r(^'$RPM_BUILD_ROOT'), "")' > %{name}-%{version}-filelist

%files -f %{name}-%{version}-filelist
%defattr(-,root,root)
%doc BUGS Changelog COPYING %{name}*.html %{name}.conf.rd README INSTALL TODO
%config %{_sysconfdir}/%{name}.conf
%config %{_sysconfdir}/profile.d/%{name}.*
%dir %{_prefix}/%{name}
%dir %{_prefix}/%{name}/bin

%changelog
* Sat Feb 26 2005 Ian Macdonald <ian@caliban.org> 0.7.1-1
- Catch SIGPIPE while exiting.

* Sun Oct 31 2004 Ian Macdonald <ian@caliban.org> 0.7.0-1
- Make it possible to use regular expressions in program specs.
- If programs were symlinked to acoc and %{_prefix}/%{name}/bin occurred
  multiple times in $PATH, then acoc could be accidentally reinvoked.

* Sat Oct 23 2004 Ian Macdonald <ian@caliban.org> 0.6.0-1
- 0.6.0
- Allow a user-definable config file to be given in $ACOCRC.
- Some new colouring specs were added.

* Wed Oct 13 2004 Ian Macdonald <ian@caliban.org> 0.5.2-2
- Include patch to disable troublesome commands in Google environment.
  Apply with '--with google'.

* Mon Apr  5 2004 Ian Macdonald <ian@caliban.org> 0.5.2-1
- 0.5.2
- handle single quote in expanded command line arguments
- expand ARGV array when passing to colour method
- remove a superfluous debugging statement

* Wed Feb  4 2004 Ian Macdonald <ian@caliban.org> 0.5.1-1
- 0.5.1
- properly catch Errno::ECHILD

* Mon Jan 12 2004 Ian Macdonald <ian@caliban.org> 0.5.0-1
- 0.5.0
- catch SIGCHLD and correctly pass back exit status of child program

* Wed Dec 10 2003 Ian Macdonald <ian@caliban.org> 0.4.7-1
- 0.4.7
- /r flag had no effect on second and subsequent program specs

* Fri Sep 12 2003 Ian Macdonald <ian@caliban.org> 0.4.6-1
- 0.4.6
- programs run in pseudo-tty should not run in their own session
- ping needs a pseudo-tty, as its behaviour changes on isatty(3)

* Wed Jul 30 2003 Ian Macdonald <ian@caliban.org> 0.4.5-1
- 0.4.5
- fix signal handling

* Fri Jul 18 2003 Ian Macdonald <ian@caliban.org> 0.4.4-1
- 0.4.4
- Ruby 1.6.x can't take rescue as a statement modifier

* Fri Jul 18 2003 Ian Macdonald <ian@caliban.org> 0.4.3-1
- 0.4.3
- go back to using Ruby/TPty, as PTY is unreliable
- signal handler didn't actually exit the program

* Wed Jul 16 2003 Ian Macdonald <ian@caliban.org> 0.4.2-1
- 0.4.2
- no colouring if $ACOC set to 'none'
- use standard PTY module, rather than Ruby/TPty
- code clean-up

* Tue Jul  8 2003 Ian Macdonald <ian@caliban.org> 0.4.1-1
- 0.4.1
- fix bug wherby arguments with white space were expanded to multiple
  arguments

* Sun Jul  6 2003 Ian Macdonald <ian@caliban.org> 0.4.0-1
- 0.4.0
- allow per-invocation config stanzas to be defined
- rework config file to take advantage of per-invocation colouring

* Sun Jun 29 2003 Ian Macdonald <ian@caliban.org> 0.3.0-1
- 0.3.0
- new program flag /p requests allocation of a pseudo-terminal through which
  to run the target program (requires optional Ruby/TPty library)
- merely exec() the program if there *is* a configuration stanza, but it
  contains no rules
- code clean-up
- configure ls to get a pseudo-terminal

* Wed Jun 25 2003 Ian Macdonald <ian@caliban.org> 0.2.6-1
- 0.2.6
- new program flag /r removes all previous matching rules for given program
- building with '--with per_user' patches the files that go into
  /etc/profile.d, so that ~/.acoc must exist before the path will be modified

* Sat Jun 21 2003 Ian Macdonald <ian@caliban.org> 0.2.5-1
- 0.2.5
- by default, no colouring will take place if stdout is not a tty
- new program flag /t allows colouring to take place even when stdout
  is not a tty
- add new BUGS file

* Fri Jun 20 2003 Ian Macdonald <ian@caliban.org> 0.2.1-1
- 0.2.1
- new config sections for tcpdump, ldd, nm, strace, ltrace, id and ls
- diff config now also applies to rcsdiff
- make config now also applies to gmake
- tarball now includes Term::ANSIColor for lazy people

* Wed Jun 11 2003 Ian Macdonald <ian@caliban.org> 0.2.0-1
- 0.2.0
- catch SIGPIPE while printing
- error message if we're called on a non-existent program should go to
  stderr, not stdout
- program flags are now cumulative with each stanza for programs that have
  multiple stanzas
- diff rules now handle standard and context format output
- rpmbuild rules broken out into gcc and make rules

* Sat Jun  7 2003 Ian Macdonald <ian@caliban.org> 0.1.0-1
- 0.1.0, first public release
- program renamed acoc
- full documentation included

* Fri Jun  6 2003 Ian Macdonald <ian@caliban.org> 0.1.0pre3-1
- 0.1.0pre3-1
- program renamed from rc to rcf
- config rules for df, route and ifconfig

* Thu Jun  5 2003 Ian Macdonald <ian@caliban.org> 0.1.0pre2-1
- 0.1.0pre2-1
- multiple colours can be specified for a single match component,
  e.g. bold+green
- add more rules to rcf.conf
- improve documentation
- building with '--with links' populates %%{_prefix}/%%{name}/bin with
  links to all programs for which rcf.conf contains configurations

* Tue Jun  3 2003 Ian Macdonald <ian@caliban.org> 0.1.0pre1-1
- 0.1.0pre1-1
